@@ -2,24 +2,24 @@ extern crate alloc;
 
 use alloc::collections::BTreeMap;
 
-use crate::Value;
+use crate::StateValue;
 
-pub struct StateManager<'a> {
-    state: BTreeMap<u32, Value<'a>>,
+pub struct StateManager {
+    state: BTreeMap<u32, StateValue>,
 }
 
-impl<'a> StateManager<'a> {
+impl StateManager {
     pub fn new() -> Self {
         Self {
             state: BTreeMap::new(),
         }
     }
 
-    pub fn get_value(&self, index: u32) -> Option<&Value> {
+    pub fn get_value(&self, index: u32) -> Option<&StateValue> {
         self.state.get(&index)
     }
 
-    pub fn set_value(&mut self, index: u32, value: Value<'a>) {
+    pub fn set_value(&mut self, index: u32, value: StateValue) {
         self.state.insert(index, value);
     }
 }
